# coding: utf-8

"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://app.elasticemail.com/marketing/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ElasticEmail.models.verification_file_result_details import VerificationFileResultDetails

class TestVerificationFileResultDetails(unittest.TestCase):
    """VerificationFileResultDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VerificationFileResultDetails:
        """Test VerificationFileResultDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VerificationFileResultDetails`
        """
        model = VerificationFileResultDetails()
        if include_optional:
            return VerificationFileResultDetails(
                verification_result = [
                    ElasticEmail.models.email_validation_result.EmailValidationResult(
                        account = '', 
                        domain = 'example.com', 
                        email = '', 
                        suggested_spelling = '', 
                        disposable = True, 
                        role = True, 
                        reason = '', 
                        date_added = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        result = 'None', 
                        predicted_score = 1.337, 
                        predicted_status = 'None', )
                    ],
                verification_id = '',
                filename = '',
                verification_status = 'Processing',
                file_upload_result = ElasticEmail.models.file_upload_result.FileUploadResult(
                    emails_count = 56, 
                    duplicated_emails_count = 56, ),
                date_added = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                source = ''
            )
        else:
            return VerificationFileResultDetails(
        )
        """

    def testVerificationFileResultDetails(self):
        """Test VerificationFileResultDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
