# flake8: noqa

# import apis into api package
from ElasticEmail.api.campaigns_api import CampaignsApi
from ElasticEmail.api.contacts_api import ContactsApi
from ElasticEmail.api.domains_api import DomainsApi
from ElasticEmail.api.emails_api import EmailsApi
from ElasticEmail.api.events_api import EventsApi
from ElasticEmail.api.files_api import FilesApi
from ElasticEmail.api.inbound_route_api import InboundRouteApi
from ElasticEmail.api.lists_api import ListsApi
from ElasticEmail.api.security_api import SecurityApi
from ElasticEmail.api.segments_api import SegmentsApi
from ElasticEmail.api.statistics_api import StatisticsApi
from ElasticEmail.api.sub_accounts_api import SubAccountsApi
from ElasticEmail.api.suppressions_api import SuppressionsApi
from ElasticEmail.api.templates_api import TemplatesApi
from ElasticEmail.api.verifications_api import VerificationsApi

